@@ -25,6 +25,11 @@ def cli():
     default=None,
     help="Name of RL method to use in experiment.",
 )
+@click.option(
+    "--gym",
+    default=None,
+    help="Name of gym framework to use in experiment.",
+)
 @click.option(
     "--env",
     default=None,
@@ -82,9 +87,15 @@ def cli():
     default=None,
     help="For developer use only: location of custom beobench package version.",
 )
+@click.option(
+    "--force-build",
+    is_flag=True,
+    help="whether to force a re-build, even if image already exists.",
+)
 def run(
     config: str,
     method: str,
+    gym: str,
     env: str,
     local_dir: str,
     wandb_project: str,
@@ -96,6 +107,7 @@ def run(
     no_additional_container: bool,
     use_no_cache: bool,
     dev_path: str,
+    force_build: bool,
 ) -> None:
     """Run beobench experiment from command line.
 
@@ -110,6 +122,7 @@ def run(
     beobench.experiment.scheduler.run(
         config=list(config),
         method=method,
+        gym=gym,
         env=env,
         local_dir=local_dir,
         wandb_project=wandb_project,
@@ -121,6 +134,7 @@ def run(
         no_additional_container=no_additional_container,
         use_no_cache=use_no_cache,
         dev_path=dev_path,
+        force_build=force_build,
     )
 
 
